@@ -1,12 +1,14 @@
 import abc
 
 from kupala.application import Kupala
-from kupala.container import Container
 
 
 class Provider(abc.ABC):
+    def configure(self, app: Kupala) -> None:
+        pass
+
     def register(self, app: Kupala) -> None:
         pass
 
-    def bootstrap(self, container: Container) -> None:
+    def bootstrap(self, app: Kupala) -> None:
         pass
